local SM = AceLibrary("SharedMedia-1.0")
local Graph = AceLibrary("Graph-1.0")

local me={}

function me:CreateIconFrame(parent,texture,title,text)
	local theFrame=CreateFrame("Frame",nil,parent)
	theFrame:SetWidth(18)
	theFrame:SetHeight(18)

	theFrame.texture=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.texture:SetAllPoints(theFrame)
	theFrame.texture:SetTexture(texture)
	theFrame.title=title
	theFrame.text=text

	theFrame:SetScript("OnEnter",function()
					GameTooltip:SetOwner(theFrame, "ANCHOR_TOPRIGHT")
					GameTooltip:ClearLines()
					GameTooltip:AddLine(theFrame.title)
					GameTooltip:AddLine(theFrame.text,1,1,1,true)
					GameTooltip:Show()
				     end)
	theFrame:SetScript("OnLeave",function() GameTooltip:Hide() end)

	theFrame:EnableMouse()
	theFrame:Show()

	return theFrame
end

function me:ConfigureCheckbox(check)
	check:SetWidth(20)
	check:SetHeight(20)
	check:SetScript("OnClick",function () if this:GetChecked() then this:SetChecked(true) else this:SetChecked(false) end end)
	check:SetNormalTexture("Interface\\Buttons\\UI-CheckBox-Up")
	check:SetPushedTexture("Interface\\Buttons\\UI-CheckBox-Down")
	check:SetDisabledCheckedTexture("Interface\\Buttons\\UI-CheckBox-Check-Disabled")
	check:SetCheckedTexture("Interface\\Buttons\\UI-CheckBox-Check")
	check:SetHighlightTexture("Interface\\Buttons\\UI-CheckBox-Highlight")

end

function me:CreateRow(parent,label,header)
	local theFrame=CreateFrame("Frame",nil,parent)

	theFrame:SetWidth(196)
	theFrame:SetHeight(18)
	
	theFrame.Label=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	if not header then
		theFrame.Label:SetTextColor(1,1,1,1)
	end
	theFrame.Label:SetText(" "..label)
	theFrame.Label:SetPoint("LEFT",theFrame,"LEFT",0,0)

	theFrame.ShowData=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.ShowData)

	theFrame.RecordData=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.RecordData)
	theFrame.RecordData:SetScript("OnClick",function () if this:GetChecked() then this:SetChecked(true);theFrame.RecordTime:Enable();theFrame.TrackDeaths:Enable();theFrame.TrackBuffs:Enable() else this:SetChecked(false);theFrame.RecordTime:Disable();theFrame.TrackDeaths:Disable();theFrame.TrackBuffs:Disable() end end)


	theFrame.RecordTime=CreateFrame("CheckButton",nil,theFrame)	
	me:ConfigureCheckbox(theFrame.RecordTime)

	theFrame.TrackDeaths=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.TrackDeaths)

	theFrame.TrackBuffs=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.TrackBuffs)


	theFrame.ShowData:SetPoint("RIGHT",theFrame.RecordData,"LEFT",0,0)
	theFrame.RecordData:SetPoint("RIGHT",theFrame.RecordTime,"LEFT",0,0)
	theFrame.RecordTime:SetPoint("RIGHT",theFrame.TrackDeaths,"LEFT",0,0)
	theFrame.TrackDeaths:SetPoint("RIGHT",theFrame.TrackBuffs,"LEFT",0,0)
	theFrame.TrackBuffs:SetPoint("RIGHT",theFrame,"RIGHT",-1,0)

	theFrame.ShowData:Show()
	theFrame.RecordData:Show()
	theFrame.RecordTime:Show()
	theFrame.TrackDeaths:Show()
	theFrame.TrackBuffs:Show()

	return theFrame
end

function me:SetupFilterOptions(parent)
	me.FilterOptions=CreateFrame("Frame",nil,parent)
	local theFrame=me.FilterOptions

	theFrame:SetHeight(196)
	theFrame:SetWidth(196)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",2,-34)

	theFrame.Title_Show=me:CreateIconFrame(theFrame,"Interface/Icons/INV_Misc_Eye_01","Show","Whether this type is shown in the main window")
	theFrame.Title_Data=me:CreateIconFrame(theFrame,"Interface/Icons/INV_Misc_Note_02","Record Data","Whether data is recorded for this type")
	theFrame.Title_Time=me:CreateIconFrame(theFrame,"Interface/Icons/INV_Misc_PocketWatch_02","Record Time Data","Whether time data is recorded for this type")
	theFrame.Title_Deaths=me:CreateIconFrame(theFrame,"Interface/Icons/Ability_Creature_Cursed_02","Record Deaths","Records when deaths occur and the past few actions involving this type")
	theFrame.Title_Buffs=me:CreateIconFrame(theFrame,"Interface/Icons/Ability_Warrior_SavageBlow","Record Buffs/Debuffs","Records the times and applications of buff/debuffs on this type")
	
	theFrame.Title_Show:SetPoint("RIGHT",theFrame.Title_Data,"LEFT",-2,0)
	theFrame.Title_Data:SetPoint("RIGHT",theFrame.Title_Time,"LEFT",-2,0)
	theFrame.Title_Time:SetPoint("RIGHT",theFrame.Title_Deaths,"LEFT",-2,0)
	theFrame.Title_Deaths:SetPoint("RIGHT",theFrame.Title_Buffs,"LEFT",-2,0)
	theFrame.Title_Buffs:SetPoint("TOPRIGHT",theFrame,"TOPRIGHT",-2,-2)

	theFrame.Title=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Title:SetText("Filters")
	theFrame.Title:SetPoint("TOPLEFT",theFrame,"TOPLEFT",2,-4)



	theFrame.Filters={}
	local Filters=theFrame.Filters

	theFrame.TitlePlayers=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.TitlePlayers:SetText(" Players")
	theFrame.TitlePlayers:SetPoint("TOPLEFT",theFrame,"TOPLEFT",0,-26)

	Filters.Grouped=me:CreateRow(theFrame,"  Grouped")
	Filters.Grouped:SetPoint("TOPLEFT",theFrame.TitlePlayers,"BOTTOMLEFT",0,-2)

	Filters.Ungrouped=me:CreateRow(theFrame,"  Ungrouped")
	Filters.Ungrouped:SetPoint("TOP",Filters.Grouped,"BOTTOM",0,-2)


	Filters.Pet=me:CreateRow(theFrame,"Pets",true)
	Filters.Pet:SetPoint("TOP",Filters.Ungrouped,"BOTTOM",0,-2)

	theFrame.TitleMobs=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.TitleMobs:SetText(" Mobs")
	theFrame.TitleMobs:SetPoint("TOPLEFT",Filters.Pet,"BOTTOMLEFT",0,-2)

	Filters.Trivial=me:CreateRow(theFrame,"  Trivial")
	Filters.Trivial:SetPoint("TOPLEFT",theFrame.TitleMobs,"BOTTOMLEFT",0,-2)

	Filters.Nontrivial=me:CreateRow(theFrame,"  Non-Trivial")
	Filters.Nontrivial:SetPoint("TOP",Filters.Trivial,"BOTTOM",0,-2)

	Filters.Boss=me:CreateRow(theFrame,"  Bosses")
	Filters.Boss:SetPoint("TOP",Filters.Nontrivial,"BOTTOM",0,-2)

	Filters.Unknown=me:CreateRow(theFrame,"Unknown",true)
	Filters.Unknown:SetPoint("TOP",Filters.Boss,"BOTTOM",0,-2)
end


function me:SetBarTexture()
	local BarTextures=SM:List("statusbar")
	if Recount.db.char.GlobalStatusBar then
		SM:SetGlobal("statusbar",BarTextures[this.value])
	else
		Recount:SetBarTextures(BarTextures[this.value])
	end
	UIDropDownMenu_SetSelectedID(me.MiscOptions.StatusBarDropDown,this.value);
end

function me:BarTextureDropDown_Initialize()	
	local BarTextures=SM:List("statusbar")
	local LookingFor

	if Recount.db.char.GlobalStatusBar then
		LookingFor=SM:GetGlobal("statusbar")
	end

	if not LookingFor then
		LookingFor=Recount.db.char.BarTexture
	end

	if not LookingFor then
		LookingFor="BantoBar"
	end

	for k,v in pairs(BarTextures) do
		info = {};
		info.text = v;
		info.value = k;
		info.func = me.SetBarTexture;
		UIDropDownMenu_AddButton(info);
		if v==LookingFor then
			LookingFor=k
		end
	end

	UIDropDownMenu_SetSelectedID(me.MiscOptions.StatusBarDropDown,LookingFor);
end

function me:SetupMiscOptions(parent)
	me.MiscOptions=CreateFrame("Frame",nil,parent)
	local theFrame=me.MiscOptions

	theFrame:SetHeight(196)
	theFrame:SetWidth(196)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",200,-34)

	theFrame.GlobalStatusBar=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.GlobalStatusBar)
	theFrame.GlobalStatusBar:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,0)

	theFrame.GlobalStatusBarText=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.GlobalStatusBarText:SetText("Use Global Textures")
	theFrame.GlobalStatusBarText:SetPoint("LEFT",theFrame.GlobalStatusBar,"RIGHT",4,0)

	theFrame.StatusBarDropDown=CreateFrame("Frame","Recount_Config_BarDropdown",theFrame,"UIDropDownMenuTemplate")
	theFrame.StatusBarDropDown:SetPoint("TOPLEFT",theFrame,"TOPLEFT",64,-26)
	theFrame.StatusBarDropDown:SetScale(0.91)
	theFrame.StatusBarDropDown.Title=theFrame.StatusBarDropDown:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.StatusBarDropDown.Title:SetText("Bar Texture:")
	theFrame.StatusBarDropDown.Title:SetPoint("RIGHT",theFrame.StatusBarDropDown,"LEFT",14,0)
	UIDropDownMenu_Initialize(theFrame.StatusBarDropDown, me.BarTextureDropDown_Initialize);

	theFrame.Autodelete=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.Autodelete)
	theFrame.Autodelete:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,-56)

	theFrame.AutodeleteText=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.AutodeleteText:SetText("Autodelete Time Data")
	theFrame.AutodeleteText:SetPoint("LEFT",theFrame.Autodelete,"RIGHT",4,0)

	local slider = CreateFrame("Slider", "Recount_ConfigWindow_TimeData_Slider", theFrame,"OptionsSliderTemplate")
	theFrame.TimeDataSlider=slider
	slider:SetOrientation("HORIZONTAL")
	slider:SetMinMaxValues(30, 300)
	slider:SetValueStep(5)
	slider:SetValue(30)
	slider:SetWidth(180)
	slider:SetHeight(16)
	slider:SetPoint("TOP", theFrame, "TOP", 0, -90)
	slider:SetScript("OnValueChanged",function() getglobal(this:GetName().."Text"):SetText("Save Time Data For: "..this:GetValue().. " Minutes") end)
	getglobal(slider:GetName().."High"):SetText("300");
	getglobal(slider:GetName().."Low"):SetText("30");
	getglobal(slider:GetName().."Text"):SetText("Save Time Data For: "..slider:GetValue().. " Minutes")

	theFrame.CombatLogRange=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.CombatLogRange)
	theFrame.CombatLogRange:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,-120)

	theFrame.CombatLogRangeText=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.CombatLogRangeText:SetText("Set Combat Log Range")
	theFrame.CombatLogRangeText:SetPoint("LEFT",theFrame.CombatLogRange,"RIGHT",4,0)

	local slider = CreateFrame("Slider", "Recount_ConfigWindow_CombatLogRange_Slider", theFrame,"OptionsSliderTemplate")
	theFrame.CombatLogRangeSlider=slider
	slider:SetOrientation("HORIZONTAL")
	slider:SetMinMaxValues(40, 200)
	slider:SetValueStep(5)
	slider:SetValue(40)
	slider:SetWidth(180)
	slider:SetHeight(16)
	slider:SetPoint("TOP", theFrame, "TOP", 0, -154)
	slider:SetScript("OnValueChanged",function() getglobal(this:GetName().."Text"):SetText("Combat Log Range: "..this:GetValue().. " Yds") end)
	getglobal(slider:GetName().."High"):SetText("200");
	getglobal(slider:GetName().."Low"):SetText("40");
	getglobal(slider:GetName().."Text"):SetText("Combat Log Range: "..slider:GetValue().. " Yds")
end

function me:SetupButtonOptions(parent)
	me.ButtonOptions=CreateFrame("Frame",nil,parent)
	local theFrame=me.ButtonOptions

	theFrame:SetHeight(196)
	theFrame:SetWidth(196)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",400,-34)
	--Reset
	--File
	--Config
	--Report

	theFrame.ButtonsTitle=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.ButtonsTitle:SetText("Show Buttons")
	theFrame.ButtonsTitle:SetPoint("TOP",theFrame,"TOPLEFT",100,0)
	
	theFrame.ResetButton=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.ResetButton)
	theFrame.ResetButton:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,-18)

	theFrame.Reset_Icon=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.Reset_Icon:SetWidth(16)
	theFrame.Reset_Icon:SetHeight(16)
	theFrame.Reset_Icon:SetTexture("Interface\\Addons\\Recount\\Textures\\icon-reset")
	theFrame.Reset_Icon:SetPoint("LEFT",theFrame.ResetButton,"RIGHT",2,0)

	theFrame.Reset_Text=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Reset_Text:SetText("Reset")
	theFrame.Reset_Text:SetPoint("LEFT",theFrame.Reset_Icon,"RIGHT",2,0)

	theFrame.FileButton=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.FileButton)
	theFrame.FileButton:SetPoint("TOP",theFrame.ResetButton,"BOTTOM",0,-2)

	theFrame.File_Icon=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.File_Icon:SetWidth(16)
	theFrame.File_Icon:SetHeight(16)
	theFrame.File_Icon:SetTexture("Interface\\Buttons\\UI-GuildButton-PublicNote-Up.blp")
	theFrame.File_Icon:SetPoint("LEFT",theFrame.FileButton,"RIGHT",2,0)

	theFrame.File_Text=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.File_Text:SetText("File")
	theFrame.File_Text:SetPoint("LEFT",theFrame.File_Icon,"RIGHT",2,0)

	theFrame.ConfigButton=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.ConfigButton)
	theFrame.ConfigButton:SetPoint("TOPLEFT",theFrame,"TOPLEFT",100,-18)

	theFrame.Config_Icon=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.Config_Icon:SetWidth(16)
	theFrame.Config_Icon:SetHeight(16)
	theFrame.Config_Icon:SetTexture("Interface\\Addons\\Recount\\Textures\\icon-config")
	theFrame.Config_Icon:SetPoint("LEFT",theFrame.ConfigButton,"RIGHT",2,0)

	theFrame.Config_Text=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Config_Text:SetText("Config")
	theFrame.Config_Text:SetPoint("LEFT",theFrame.Config_Icon,"RIGHT",2,0)

	theFrame.ReportButton=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.ReportButton)
	theFrame.ReportButton:SetPoint("TOP",theFrame.ConfigButton,"BOTTOM",0,-2)

	theFrame.Report_Icon=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.Report_Icon:SetWidth(16)
	theFrame.Report_Icon:SetHeight(16)
	theFrame.Report_Icon:SetTexture("Interface\\Buttons\\UI-GuildButton-MOTD-Up.blp")
	theFrame.Report_Icon:SetPoint("LEFT",theFrame.ReportButton,"RIGHT",2,0)

	theFrame.Report_Text=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Report_Text:SetText("Report")
	theFrame.Report_Text:SetPoint("LEFT",theFrame.Report_Icon,"RIGHT",2,0)

end

function me:CreateConfigWindow()
	me.ConfigWindow=CreateFrame("Frame","Recount_ConfigWindow",UIParent)

	local theFrame=me.ConfigWindow

	theFrame:ClearAllPoints()
	theFrame:SetPoint("CENTER",UIParent)
	theFrame:SetHeight(232+32)
	theFrame:SetWidth(600)

	theFrame:SetBackdrop({
		bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = true, tileSize = 16,
		edgeFile = "Interface\\AddOns\\Recount\\textures\\otravi-semi-full-border", edgeSize = 32,
		insets = {left = 1, right = 1, top = 20, bottom = 1},
	})
	theFrame:SetBackdropBorderColor(1.0,0.0,0.0)
	theFrame:SetBackdropColor(24/255, 24/255, 24/255)

	theFrame:EnableMouse(true)
	theFrame:SetMovable(true)


	theFrame:SetScript("OnMouseDown", function() 
						if ( ( ( not this.isLocked ) or ( this.isLocked == 0 ) ) and ( arg1 == "LeftButton" ) ) then
						  Recount:SetWindowTop(this)
						  this:StartMoving();
						  this.isMoving = true;
						 end
						end)
	theFrame:SetScript("OnMouseUp", function() 
						if ( this.isMoving ) then
						  this:StopMovingOrSizing();
						  this.isMoving = false;
						 end
						end)
	theFrame:SetScript("OnShow", function()
						Recount:SetWindowTop(this)
						end)
					
	theFrame:SetScript("OnHide", function()  if ( this.isMoving ) then
						  this:StopMovingOrSizing();
						  this.isMoving = false;
						 end
						end)
	
	theFrame.Title=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Title:SetPoint("TOPLEFT",theFrame,"TOPLEFT",6,-15)
	theFrame.Title:SetTextColor(1.0,1.0,1.0)
	theFrame.Title:SetText("Config Recount")

	theFrame.SaveButton=CreateFrame("Button",nil,theFrame,"OptionsButtonTemplate")
	theFrame.SaveButton:SetWidth(90)
	theFrame.SaveButton:SetHeight(24)
	theFrame.SaveButton:SetPoint("BOTTOMRIGHT",theFrame,"BOTTOM",-2,4)
	theFrame.SaveButton:SetScript("OnClick",function() me:SaveConfig() end)
	theFrame.SaveButton:SetText("Save")

	theFrame.RevertButton=CreateFrame("Button",nil,theFrame,"OptionsButtonTemplate")
	theFrame.RevertButton:SetWidth(90)
	theFrame.RevertButton:SetHeight(24)
	theFrame.RevertButton:SetPoint("BOTTOMLEFT",theFrame,"BOTTOM",2,4)
	theFrame.RevertButton:SetScript("OnClick",function() me:LoadConfig() end)
	theFrame.RevertButton:SetText("Revert")


	theFrame.CloseButton=CreateFrame("Button",nil,theFrame)
	theFrame.CloseButton:SetNormalTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Up.blp")
	theFrame.CloseButton:SetPushedTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Down.blp")
	theFrame.CloseButton:SetHighlightTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Highlight.blp")
	theFrame.CloseButton:SetWidth(20)
	theFrame.CloseButton:SetHeight(20)
	theFrame.CloseButton:SetPoint("TOPRIGHT",theFrame,"TOPRIGHT",-4,-12)
	theFrame.CloseButton:SetScript("OnClick",function() this:GetParent():Hide() end)

	me:SetupFilterOptions(theFrame)
	Graph:DrawLine(theFrame,200,32,200,233,24,{0.5,0.0,0.0,1.0},"ARTWORK")
	me:SetupMiscOptions(theFrame)
	Graph:DrawLine(theFrame,400,32,400,233,24,{0.5,0.0,0.0,1.0},"ARTWORK")
	 me:SetupButtonOptions(theFrame)
	theFrame:Hide()

	--Need to add it to our window ordering system
	Recount:AddWindow(theFrame)
end

function me:LoadConfig()
	for k, v in pairs(me.FilterOptions.Filters) do
		v.ShowData:SetChecked(Recount.db.char.Filters.Show[k])
		v.RecordData:SetChecked(Recount.db.char.Filters.Data[k])
		v.RecordTime:SetChecked(Recount.db.char.Filters.TimeData[k])
		v.TrackDeaths:SetChecked(Recount.db.char.Filters.TrackDeaths[k])		
	end

	for k, v in pairs(Recount.db.char.MainWindow.Buttons) do
		me.ButtonOptions[k]:SetChecked(v)
	end

	me.MiscOptions.Autodelete:SetChecked(Recount.db.char.AutoDelete)
	me.MiscOptions.TimeDataSlider:SetValue(Recount.db.char.AutoDeleteTime)
	me.MiscOptions.GlobalStatusBar:SetChecked(Recount.db.char.GlobalStatusBar)
	me.MiscOptions.CombatLogRange:SetChecked(Recount.db.char.UseCombatLogRange)
	me.MiscOptions.CombatLogRangeSlider:SetValue(Recount.db.char.CombatLogRange)

end

function me:SaveConfig()
	for k, v in pairs(me.FilterOptions.Filters) do
		Recount.db.char.Filters.Show[k]=v.ShowData:GetChecked()==1
		Recount.db.char.Filters.Data[k]=v.RecordData:GetChecked()==1
		Recount.db.char.Filters.TimeData[k]=v.RecordTime:GetChecked()==1
		Recount.db.char.Filters.TrackDeaths[k]=v.TrackDeaths:GetChecked()==1
	end

	for k, v in pairs(Recount.db.char.MainWindow.Buttons) do
		Recount.db.char.MainWindow.Buttons[k]=(me.ButtonOptions[k]:GetChecked()==1)
	end

	Recount.db.char.AutoDelete=me.MiscOptions.Autodelete:GetChecked()==1
	Recount.db.char.AutoDeleteTime=me.MiscOptions.TimeDataSlider:GetValue()

	Recount.db.char.GlobalStatusBar=me.MiscOptions.GlobalStatusBar:GetChecked()==1

	Recount.db.char.UseCombatLogRange=me.MiscOptions.CombatLogRange:GetChecked()==1
	Recount.db.char.CombatLogRange=me.MiscOptions.CombatLogRangeSlider:GetValue()

	if Recount.db.char.UseCombatLogRange then
		Recount:SetLogRange(Recount.db.char.CombatLogRange)
	else
		Recount:SetLogRangeDefault() 
	end


	Recount.MainWindow.DispTableSorted={}
	Recount.MainWindow.DispTableLookup={}

	Recount:SetupMainWindowButtons()
	Recount:RefreshMainWindow()
end

function Recount:ShowConfig()
	if type(me.ConfigWindow)=="nil" then
		me:CreateConfigWindow()
	end
	me:LoadConfig()
	me.ConfigWindow:Show()
end


function Recount:ConfigWindowStatus()
	if me.ConfigWindow.Below then
		below = me.ConfigWindow.Below:GetName()
	else
		below = "(nil)"
	end

	if me.ConfigWindow.Above then
		above = me.ConfigWindow.Above:GetName()
	else
		above = "(nil)"
	end

	Recount:Print(below.." Config "..above)
end